@@ -24,7 +24,6 @@
 ----------------------------------------------------------------------*/
 
 #include <ctype.h>
-#include <string.h>
 #include "glpapi.h"
 
 /*----------------------------------------------------------------------
@@ -37,24 +36,21 @@
 --
 -- *Description*
 --
--- The glp_check_name routine checks the given symbolic name for
+-- The routine glp_check_name checks the given symbolic name for
 -- correctness.
 --
--- The symbolic name is considered as correct if it contains from 1 up
--- to 255 arbitrary characters, except control and space characters.
+-- Symbolic name is considered as correct if it consists of 1 up to 255
+-- graphic characters.
 --
 -- *Returns*
 --
--- 0 - the given symbolic name is valid;
--- 1 - the character string name has invalid length;
--- 2 - the character string name contains control or/and space
---     characters. */
+-- If the given symbolic name is correct, the routine returns zero.
+-- Otherwise the routine returns non-zero. */
 
 int glp_check_name(char *name)
-{     int len = strlen(name), k;
-      if (!(1 <= len && len <= GLP_MAX_NAME)) return 1;
-      for (k = 0; k < len; k++)
-         if (iscntrl(name[k]) || name[k] == ' ') return 2;
+{     int t;
+      for (t = 0; name[t] != '\0'; t++)
+         if (t == 255 || !isgraph(name[t])) return 1;
       return 0;
 }
 
