@@ -63,7 +63,7 @@ void glp_delete_cols(LPI *lp, int flag[])
             n++;
             lp->col[n] = lp->col[j];
             lp->col[n]->seqn = n;
-            for (e = lp->col[j]->ptr; e != NULL; e = e->col) e->j = n;
+            for (e = lp->col[n]->ptr; e != NULL; e = e->col) e->j = n;
          }
       }
       lp->n = n;
