@@ -63,7 +63,7 @@ void glp_delete_rows(LPI *lp, int flag[])
             m++;
             lp->row[m] = lp->row[i];
             lp->row[m]->seqn = m;
-            for (e = lp->row[i]->ptr; e != NULL; e = e->row) e->i = m;
+            for (e = lp->row[m]->ptr; e != NULL; e = e->row) e->i = m;
          }
       }
       lp->m = m;
