@@ -23,8 +23,8 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include "glpimg.h"
+#include "glpset.h"
 
 /*----------------------------------------------------------------------
 -- get_imgval - get current value of pixel.
@@ -80,7 +80,7 @@ int get_imgval(IMG *img, int x, int y)
             val = *scan & 255;
             break;
          default:
-            assert(img->type != img->type);
+            insist(img->type != img->type);
       }
 skip: return val;
 }
