@@ -208,11 +208,11 @@ static double alfa_aff_p, alfa_aff_d;
 /* maximal primal and dual stepsizes in the affine scaling direction,
    on which x and z are still non-negative */
 
-double mu_aff;
+static double mu_aff;
 /* duality measure mu_aff = x_aff'*z_aff/n in the boundary point
    x_aff' = x+alfa_aff_p*dx_aff, z_aff' = z+alfa_aff_d*dz_aff */
 
-double sigma;
+static double sigma;
 /* the parameter chosen using Mehrotra's heuristic (0 <= sigma <= 1) */
 
 static double *dx_cc; /* double dx_cc[1:n]; */
