@@ -45,8 +45,8 @@
 --
 -- *Returns*
 --
--- The scrape_mat routine returns the total number of elements, which
--- have been removed from the matrix. */
+-- The scrape_mat routine returns total number of elements which have
+-- been removed from the matrix. */
 
 int scrape_mat(MAT *A, double eps)
 {     ELEM *e, *ee;
