@@ -39,8 +39,10 @@
 -- The get_atom routine allocates an atom (i.e. continuous space of
 -- memory) using the specified memory pool. The size of atom which
 -- should be allocated is assumed to be set when the pool was created
--- by the create_pool routine. The get_atom routine also clears the
--- allocated atom by binary zeros.
+-- by the create_pool routine.
+--
+-- Note that being allocated the atom initially contains arbitrary data
+-- (not binary zeros).
 --
 -- *Returns*
 --
@@ -49,8 +51,8 @@
 void *get_atom(POOL *pool)
 {     void *ptr;
       if (pool->size == 0)
-         fault("get_atom: pool cannot be used to allocate an atom of va"
-            "riable size");
+         fault("get_atom: pool cannot be used to allocate an atom of fi"
+            "xed size");
       /* if there is a free atom, pull it from the list */
       if (pool->avail != NULL)
       {  ptr = pool->avail;
@@ -80,7 +82,11 @@ void *get_atom(POOL *pool)
       ptr = (void *)((char *)pool->link + pool->used);
       pool->used += pool->size;
 done: pool->count++;
+#if 0
       memset(ptr, '\0', pool->size);
+#else
+      memset(ptr, '?', pool->size);
+#endif
       return ptr;
 }
 
