@@ -40,8 +40,10 @@
 -- memory) using the specified memory pool. It is assumed that the pool
 -- was created by the create_pool routine with size = 0. The actual
 -- size (in bytes) of atom which should be allocated is specified by
--- size (it should be positive and not greater than 256). The get_atomv
--- routine also clears the allocated atom by binary zeros.
+-- size (it should be positive and not greater than 256).
+--
+-- Note that being allocated the atom initially contains arbitrary data
+-- (not binary zeros).
 --
 -- *Returns*
 --
@@ -50,8 +52,8 @@
 void *get_atomv(POOL *pool, int size)
 {     void *ptr;
       if (pool->size != 0)
-         fault("get_atomv: pool cannot be used to allocate an atom of f"
-            "ixed size");
+         fault("get_atomv: pool cannot be used to allocate an atom of v"
+            "ariable size");
       if (!(1 <= size && size <= 256))
          fault("get_atomv: invalid atom size");
       /* actual atom size should be not less than sizeof(void *) and
@@ -81,7 +83,11 @@ void *get_atomv(POOL *pool, int size)
       ptr = (void *)((char *)pool->link + pool->used);
       pool->used += size;
       pool->count++;
+#if 0
       memset(ptr, '\0', size);
+#else
+      memset(ptr, '?', size);
+#endif
       return ptr;
 }
 
