@@ -45,9 +45,10 @@ int mem_cpeak = 0;
 --
 -- *Description*
 --
--- The umalloc routine allocates a memory block of size bytes long and
--- clears the allocated block by binary zeros. If the operation fails,
--- abnormal program termination occurs.
+-- The umalloc routine allocates a memory block of size bytes long.
+--
+-- Note that being allocated the memory block contains arbitrary data
+-- (not binary zeros).
 --
 -- *Returns*
 --
@@ -67,7 +68,11 @@ void *umalloc(int size)
       desc = malloc(size);
       if (desc == NULL)
          fault("umalloc: malloc failed");
+#if 0
       memset(desc, '\0', size);
+#else
+      memset(desc, '?', size);
+#endif
       desc->size = size;
       desc->flag = mem_flag;
       mem_total += size;
