@@ -26,11 +26,11 @@
 #ifndef _GLPDUFF_H
 #define _GLPDUFF_H
 
-#define create_duff           glp_create_duff
-#define include_obj           glp_include_obj
-#define exclude_obj           glp_exclude_obj
-#define reset_duff            glp_reset_duff
-#define delete_duff           glp_delete_duff
+#define create_duff           _glp_create_duff
+#define include_obj           _glp_include_obj
+#define exclude_obj           _glp_exclude_obj
+#define reset_duff            _glp_reset_duff
+#define delete_duff           _glp_delete_duff
 
 typedef struct DUFF DUFF;
 
