@@ -26,27 +26,27 @@
 #ifndef _GLPSET_H
 #define _GLPSET_H
 
-#define print                 glp_print
-#define err_flag              glp_err_flag
-#define error                 glp_error
-#define fault                 glp_fault
-#define _insist               glp_insist
-#define urand                 glp_urand
-#define mem_flag              glp_mem_flag
-#define mem_limit             glp_mem_limit
-#define mem_total             glp_mem_total
-#define mem_tpeak             glp_mem_tpeak
-#define mem_count             glp_mem_count
-#define mem_cpeak             glp_mem_cpeak
-#define umalloc               glp_umalloc
-#define ucalloc               glp_ucalloc
-#define ufree                 glp_ufree
-#define create_pool           glp_create_pool
-#define get_atom              glp_get_atom
-#define free_atom             glp_free_atom
-#define get_atomv             glp_get_atomv
-#define clear_pool            glp_clear_pool
-#define delete_pool           glp_delete_pool
+#define print                 _glp_print
+#define err_flag              _glp_err_flag
+#define error                 _glp_error
+#define fault                 _glp_fault
+#define _insist               _glp_insist
+#define urand                 _glp_urand
+#define mem_flag              _glp_mem_flag
+#define mem_limit             _glp_mem_limit
+#define mem_total             _glp_mem_total
+#define mem_tpeak             _glp_mem_tpeak
+#define mem_count             _glp_mem_count
+#define mem_cpeak             _glp_mem_cpeak
+#define umalloc               _glp_umalloc
+#define ucalloc               _glp_ucalloc
+#define ufree                 _glp_ufree
+#define create_pool           _glp_create_pool
+#define get_atom              _glp_get_atom
+#define free_atom             _glp_free_atom
+#define get_atomv             _glp_get_atomv
+#define clear_pool            _glp_clear_pool
+#define delete_pool           _glp_delete_pool
 
 extern void print(char *fmt, ...);
 /* print informative message */
