@@ -36,7 +36,7 @@
 -- based on the revised simplex method is used.
 ----------------------------------------------------------------------*/
 
-static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.0";
+static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.0.3";
 
 static char *in_fname = NULL;
 /* name of the input text file */
@@ -79,7 +79,7 @@ static int scale = 1;
 /* if this flag is set, the solver performs automatic scaling the
    problem before solving; otherwise scaling is not used */
 
-static int form = 1;
+static int form = 3;
 /* this parameter specifies what form of the basis matrix should be used
    by the solver:
    0 - PFI
@@ -168,10 +168,9 @@ static void display_help(char *my_name)
       print("   --pfi             use PFI");
       print("   --rfi-bg          use RFI + Bartels and Golub updating "
          "technique");
-      print("                     (default)");
       print("   --rfi-ft          use RFI + Forrest and Tomlin updating"
          " technique");
-      print("   --afi             use AFI");
+      print("   --afi             use AFI (default)");
       print("   --primal          find feasible solution using primal s"
          "implex");
       print("                     (default)");
